@@ -374,7 +374,7 @@ gupnp_context_constructor (GType                  type,
 
         /* Override msearch-port property if port is set, the property exists
          * and wasn't provided otherwise */
-        if (port != 0 && msearch_port != -1 && msearch_port == 0) {
+        if (port != 0 && msearch_idx != -1 && msearch_port == 0) {
                 g_value_set_uint (construct_params[msearch_idx].value, port);
         }
 
@@ -892,6 +892,17 @@ host_path_handler (G_GNUC_UNUSED SoupServer        *server,
                 goto DONE;
         }
 
+        /* Always send HTTP 1.1 for device description requests
+         * Also set Connection: close header, since the request originated
+         * from a HTTP 1.0 client
+         */
+        if (soup_message_get_http_version (msg) == SOUP_HTTP_1_0) {
+                soup_message_set_http_version (msg, SOUP_HTTP_1_1);
+                soup_message_headers_append (msg->response_headers,
+                                             "Connection",
+                                             "close");
+        }
+
         user_agent = soup_message_headers_get_one (msg->request_headers,
                                                    "User-Agent");
 
