@@ -23,6 +23,19 @@
  * SECTION:gupnp-linux-context-manager
  * @short_description: Linux-specific implementation of #GUPnPContextManager
  *
+ * This is a Linux-specific context manager which uses <ulink
+ * url="http://www.linuxfoundation.org/collaborate/workgroups/networking/netlink">Netlink</ulink>
+ * to detect the changes in network interface configurations, such as
+ * added or removed interfaces, network addresses, ...
+ *
+ * The context manager works in two phase.
+ *
+ * Phase one is the "bootstrapping" phase where we query all currently
+ * configured interfaces and addresses.
+ *
+ * Phase two is the "listening" phase where we just listen to the netlink
+ * messages that are happening and create or destroy #GUPnPContext<!-- -->s
+ * accordingly.
  */
 
 #include <config.h>
@@ -38,6 +51,9 @@
 #include <errno.h>
 #include <string.h>
 
+#include <glib.h>
+#include <gio/gio.h>
+
 #include "gupnp-linux-context-manager.h"
 #include "gupnp-context.h"
 
@@ -46,12 +62,23 @@ G_DEFINE_TYPE (GUPnPLinuxContextManager,
                GUPNP_TYPE_CONTEXT_MANAGER);
 
 struct _GUPnPLinuxContextManagerPrivate {
+        /* Socket used for IOCTL calls */
         int fd;
+
+        /* Netlink sequence number; nl_seq > 1 means bootstrapping done */
         int nl_seq;
+
+        /* Socket used to do netlink communication */
         GSocket *netlink_socket;
+
+        /* Socket source used for normal netlink communication */
         GSource *netlink_socket_source;
+
+        /* Idle source used during bootstrap */
         GSource *bootstrap_source;
 
+        /* A hash table mapping system interface indices to a NetworkInterface
+         * structure */
         GHashTable *interfaces;
 };
 
@@ -144,8 +171,7 @@ network_device_update_essid (NetworkInterface *device)
         else
                 old_essid = NULL;
 #endif
-        if (old_essid)
-                g_free (old_essid);
+        g_free (old_essid);
 }
 
 static void
@@ -200,7 +226,7 @@ context_signal_up (G_GNUC_UNUSED gpointer key,
                    gpointer               value,
                    gpointer               user_data)
 {
-    g_signal_emit_by_name (user_data, "context-available", value);
+        g_signal_emit_by_name (user_data, "context-available", value);
 }
 
 static void
@@ -208,7 +234,7 @@ context_signal_down (G_GNUC_UNUSED gpointer key,
                      gpointer               value,
                      gpointer               user_data)
 {
-    g_signal_emit_by_name (user_data, "context-unavailable", value);
+        g_signal_emit_by_name (user_data, "context-unavailable", value);
 }
 
 static void
@@ -244,10 +270,8 @@ network_device_down (NetworkInterface *device)
 static void
 network_device_free (NetworkInterface *device)
 {
-        if (device->name != NULL)
-                g_free (device->name);
-        if (device->essid != NULL)
-                g_free (device->essid);
+        g_free (device->name);
+        g_free (device->essid);
 
         if (device->contexts != NULL) {
                 GHashTableIter iter;
@@ -258,10 +282,10 @@ network_device_free (NetworkInterface *device)
                 while (g_hash_table_iter_next (&iter,
                                                (gpointer *) &key,
                                                (gpointer *) &value)) {
-                    g_signal_emit_by_name (device->manager,
-                                           "context-unavailable",
-                                           value);
-                    g_hash_table_iter_remove (&iter);
+                        g_signal_emit_by_name (device->manager,
+                                               "context-unavailable",
+                                               value);
+                        g_hash_table_iter_remove (&iter);
                 }
         }
 
@@ -301,18 +325,19 @@ on_netlink_message_available (G_GNUC_UNUSED GSocket     *socket,
 static void
 extract_info (struct nlmsghdr *header, char **label)
 {
-    int rt_attr_len;
-    struct rtattr *rt_attr;
+        int rt_attr_len;
+        struct rtattr *rt_attr;
 
-    rt_attr = IFLA_RTA (NLMSG_DATA (header));
-    rt_attr_len = IFLA_PAYLOAD (header);
-    while (RT_ATTR_OK (rt_attr, rt_attr_len)) {
-        if (rt_attr->rta_type == IFA_LABEL) {
-            *label = g_strdup ((char *) RTA_DATA (rt_attr));
-            break;
+        rt_attr = IFLA_RTA (NLMSG_DATA (header));
+        rt_attr_len = IFLA_PAYLOAD (header);
+        while (RT_ATTR_OK (rt_attr, rt_attr_len)) {
+                if (rt_attr->rta_type == IFA_LABEL) {
+                        *label = g_strdup ((char *) RTA_DATA (rt_attr));
+
+                        break;
+                }
+                rt_attr = RTA_NEXT (rt_attr, rt_attr_len);
         }
-        rt_attr = RTA_NEXT (rt_attr, rt_attr_len);
-    }
 }
 
 static gboolean
@@ -354,9 +379,8 @@ create_context (GUPnPLinuxContextManager *self,
         }
 
         /* If device isn't one we consider, silently skip address */
-        if (device->flags & NETWORK_INTERFACE_IGNORE) {
+        if (device->flags & NETWORK_INTERFACE_IGNORE)
                 return;
-        }
 
         network_device_create_context (device, label);
 }
@@ -468,6 +492,8 @@ send_netlink_request (GUPnPLinuxContextManager *self,
                            strerror (errno));
 }
 
+/* Query all available interfaces and immediately process all answers. We need
+ * to do this to be able to send RTM_GETADDR in the next step */
 static void
 query_all_network_interfaces (GUPnPLinuxContextManager *self)
 {
@@ -481,6 +507,8 @@ query_all_network_interfaces (GUPnPLinuxContextManager *self)
         g_error_free (error);
 }
 
+/* Start query of all currenly available network addresses. The answer will be
+ * processed by the normal netlink socket source call-back. */
 static void
 query_all_addresses (GUPnPLinuxContextManager *self)
 {
@@ -494,6 +522,7 @@ query_all_addresses (GUPnPLinuxContextManager *self)
         (((ifi)->ifi_flags & (IFF_MULTICAST | IFF_LOOPBACK)) && \
          !((ifi)->ifi_flags & IFF_POINTOPOINT))
 
+/* Handle status changes (up, down, new address, ...) on network interfaces */
 static void
 handle_device_status_change (GUPnPLinuxContextManager *self,
                              struct ifinfomsg         *ifi)
@@ -538,6 +567,8 @@ remove_device (GUPnPLinuxContextManager *self,
 #define NLMSG_IS_VALID(msg,len) \
         (NLMSG_OK(msg,len) && (msg->nlmsg_type != NLMSG_DONE))
 
+/* Process the raw netlink message and dispatch to helper functions
+ * accordingly */
 static void
 receive_netlink_message (GUPnPLinuxContextManager *self, GError **error)
 {
@@ -690,6 +721,8 @@ create_netlink_socket (GUPnPLinuxContextManager *self, GError **error)
         return TRUE;
 }
 
+/* public helper function to determine runtime-fallback depending on netlink
+ * availability. */
 gboolean
 gupnp_linux_context_manager_is_available (void)
 {
@@ -705,6 +738,8 @@ gupnp_linux_context_manager_is_available (void)
         return TRUE;
 }
 
+/* GObject virtual functions */
+
 static void
 gupnp_linux_context_manager_init (GUPnPLinuxContextManager *self)
 {
@@ -722,6 +757,7 @@ gupnp_linux_context_manager_init (GUPnPLinuxContextManager *self)
                                        (GDestroyNotify) network_device_free);
 }
 
+/* Constructor, kicks off bootstrapping */
 static void
 gupnp_linux_context_manager_constructed (GObject *object)
 {
